@@ -1,5 +1,7 @@
 from urllib import parse
 import urllib,pygame
+import contextlib
+import wave
 import urllib.request
 import requests,json
 import time
@@ -10,7 +12,7 @@ from urllib.parse import quote_plus
 import hashlib
 import random
 import base64
-import json
+import json,time
 speaker=1
 ak=urllib.request.urlopen("http://www.asunc.cn/ak.txt").read().decode("utf-8")
 ak=json.loads(ak)['ak']
@@ -21,8 +23,6 @@ def setvoicemode(gender):
         speaker=1
     if gender=='girl':
         speaker=5
-    global g_gender
-    g_gender = gender
 def get_ipaddress(ip, getpoint=False):
     if ip.count(".") != 3:
         return -1
@@ -52,7 +52,7 @@ def get_traffic(road,city):
         return address['description']
     else:
         return -1
-def makevoice(text, filename):
+def makevoice(text, filename,mode=1,speed=40):
     def getReqSign(params, key):
         dict_kl = sorted(params)
         s = ''
@@ -85,12 +85,11 @@ def makevoice(text, filename):
         elif filename[len(filename)-3]=='m' or filename[len(filename)-3]=='M':
             wmv='3'
 
-
     params = {'app_id': appid,
-              'speaker': speaker,
+              'speaker': mode,
               'format': wmv,
               'volume': '0',
-              'speed': '100',
+              'speed': speed * 2,
               'text': text,
               'aht': '0',
               'apc': '58',
@@ -119,7 +118,7 @@ def makevoice(text, filename):
         return res_dict['ret']
     else:
         return res_dict['ret']
-def speak(text):
+def speak(text,mode=1,speed=40):
     def getReqSign(params, key):
         dict_kl = sorted(params)
         s = ''
@@ -143,13 +142,11 @@ def speak(text):
     m.update(str(time_s).encode("utf8"))
     nonce_s = m.hexdigest()
     nonce_s = nonce_s[0:random.randint(1, 31)]
-
-
     params = {'app_id': appid,
-              'speaker': speaker,
-              'format': '3',
+              'speaker': mode,
+              'format': '2',
               'volume': '0',
-              'speed': '100',
+              'speed': speed*2,
               'text': text,
               'aht': '0',
               'apc': '58',
@@ -162,7 +159,6 @@ def speak(text):
     res = urlopen(url, s.encode())  # 网络请求
     res_str = res.read().decode()
     res_dict = eval(res_str)
-
     if res_dict['ret'] == 0:
         res_data = res_dict['data']
         res_data_format = res_data['format']
@@ -173,16 +169,20 @@ def speak(text):
         base64_data = res_data_speech
         ori_image_data = base64.b64decode(base64_data)
         try:
-            with open('alsovoice.mp3', "wb") as f:
+            with open('alsovoice.wav', "wb") as f:
                 f.write(ori_image_data)
             f.close()
+            import wave
+            fr = wave.open('alsovoice.wav', 'rb')
+            secs = fr.getnframes() / fr.getframerate()
             pygame.mixer.init()
-            pygame.mixer.music.load('alsovoice.mp3')
+            pygame.mixer.music.load("alsovoice.wav")
             pygame.mixer.music.play()
+            time.sleep(secs+0.1)
             return res_dict['ret']
         except:
             return -1
     else:
         return res_dict['ret']
 def help():
-    print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt"))
+    print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt"))
\ No newline at end of file
